package com.cashctrl.orgsync;

import com.google.gson.JsonArray;
import com.google.gson.JsonObject;

import java.util.HashMap;

/**
 * Article category API synchronize, list, read, create and update article categories.
 * @author Silian Barlogis
 * @see SyncObject
 * @see com.cashctrl.orgsync.Category
 */
public class ArticleCategory extends Category {

    /**
     * Article category constructor, initializes all needed endpoints for article category synchronization.
     * @param alphaOrganization alpha organization
     * @param betaOrganization beta organization
     */
    public ArticleCategory(Organization alphaOrganization, Organization betaOrganization) {
        super(alphaOrganization, betaOrganization, "/api/v1/inventory/article/category/list.json", "/api/v1/inventory/article/category/read.json",
                "/api/v1/inventory/article/category/create.json", "/api/v1/inventory/article/category/update.json",
                "/api/v1/inventory/article/category/tree.json");
    }

    @Override
    protected JsonObject equivalent(String searchValue, JsonArray pool) {
        for (int idx = 0; idx < pool.size(); idx++) {
            JsonObject obj = pool.get(idx).getAsJsonObject();
            if (has(obj, equalProperty) && obj.get(equalProperty).getAsString().contains(searchValue)) {
                return obj;
            }
        }
        return null;
    }

    @SuppressWarnings("DuplicatedCode")
    @Override
    protected HashMap<String, String> parametrize(SyncData syncData) {
        HashMap<String, String> data = new HashMap<>();

        JsonObject category = syncData.source();
        if (has(category, "name"))
            data.put("name", category.get("name").getAsString());
        if (has(category, "parentId"))
            data.put("parentId", Integer.toString(category.get("parentId").getAsInt()));
        if (has(category, "allocations"))
            data.put("allocations", gson.toJson(category.get("allocations").getAsJsonArray()));
        if (has(category, "sequenceNrId"))
            data.put("sequenceNrId", Integer.toString(category.get("sequenceNrId").getAsInt()));
        if (has(category, "purchaseAccountId"))
            data.put("purchaseAccountId", Integer.toString(category.get("purchaseAccountId").getAsInt()));
        if (has(category, "salesAccountId"))
            data.put("salesAccountId", Integer.toString(category.get("salesAccountId").getAsInt()));

        return data;
    }
}