package com.cashctrl.orgsync;

import com.google.gson.JsonObject;

import java.util.HashMap;

/**
 * Currency API synchronize, list, read, create and update Currencies.
 * @author Silian Barlogis
 * @see SyncObject
 */
public class Currency extends SyncObject {

    /**
     * Currency constructor, initializes all needed endpoints for currency synchronization.
     * @param alphaOrganization alpha organization
     * @param betaOrganization beta organization
     */
    public Currency(Organization alphaOrganization, Organization betaOrganization) {
        super(alphaOrganization, betaOrganization, "/api/v1/currency/list.json", "/api/v1/currency/read.json",
                "/api/v1/currency/create.json", "/api/v1/currency/update.json", "code", "currencyId");
    }

    @Override
    protected HashMap<String, String> parametrize(SyncData syncData) {
        HashMap<String, String> data = new HashMap<>();

        JsonObject currency = syncData.source();
        if (has(currency, "code"))
            data.put("code", currency.get("code").getAsString());
        if (has(currency, "description"))
            data.put("description", currency.get("description").getAsString());
        if (has(currency, "isDefault"))
            data.put("isDefault", Boolean.toString(currency.get("isDefault").getAsBoolean()));
        if (has(currency, "rate"))
            data.put("rate", Double.toString(currency.get("rate").getAsDouble()));

        return data;
    }

    @Override
    public boolean isValid(JsonObject currency) {
        return has(currency, "id") && has(currency, "code") &&
                has(currency, "lastUpdated");
    }

    @Override
    protected void vitalInfo(StringBuilder info, JsonObject currency) {
        if (has(currency, "id"))
            info.append(" id: ").append(currency.get("id"));
        if (has(currency, "name"))
            info.append(" name: ").append(currency.get("name"));
        if (has(currency, "description"))
            info.append(" description: ").append(currency.get("description"));
    }
}