package com.cashctrl.orgsync;

import com.google.gson.JsonObject;

import java.util.HashMap;

/**
 * Person category API synchronize, list, read, create and update person categories.
 * @author Silian Barlogis
 * @see SyncObject
 * @see com.cashctrl.orgsync.Category
 */
public class PersonCategory extends Category {

    /**
     * Person category constructor, initializes all needed endpoints for person category synchronization.
     * @param alphaOrganization alpha organization
     * @param betaOrganization beta organization
     */
    public PersonCategory(Organization alphaOrganization, Organization betaOrganization) {
        super(alphaOrganization, betaOrganization, "/api/v1/person/category/list.json", "/api/v1/person/category/read.json",
                "/api/v1/person/category/create.json", "/api/v1/person/category/update.json",
                "/api/v1/person/category/tree.json");
    }

    @Override
    protected HashMap<String, String> parametrize(SyncData syncData) {
        HashMap<String, String> data = new HashMap<>();

        JsonObject category = syncData.source();
        if (has(category, "name"))
            data.put("name", category.get("name").getAsString());
        if (has(category, "discountPercentage"))
            data.put("discountPercentage", Float.toString(category.get("discountPercentage").getAsFloat()));
        if (has(category, "parentId"))
            data.put("parentId", Integer.toString(category.get("parentId").getAsInt()));
        if (has(category, "sequenceNrId"))
            data.put("sequenceNrId", Integer.toString(category.get("sequenceNrId").getAsInt()));

        return data;
    }
}