package com.cashctrl.orgsync;

import com.google.gson.JsonObject;

import java.util.HashMap;

/**
 * Unit API synchronize, list, read, create and update units.
 * @author Silian Barlogis
 * @see SyncObject
 */
public class Unit extends SyncObject {

    /**
     * Unit constructor, initializes all needed endpoints for unit synchronization.
     * @param alphaOrganization alpha organization
     * @param betaOrganization beta organization
     */
    public Unit(Organization alphaOrganization, Organization betaOrganization) {
        super(alphaOrganization, betaOrganization, "/api/v1/inventory/unit/list.json", "/api/v1/inventory/unit/read.json",
                "/api/v1/inventory/unit/create.json", "/api/v1/inventory/unit/update.json", "name", "unitId");
    }

    @Override
    protected HashMap<String, String> parametrize(SyncData syncData) {
        HashMap<String, String> data = new HashMap<>();

        JsonObject unit = syncData.source();
        if (has(unit, "name"))
            data.put("name", unit.get("name").getAsString());

        return data;
    }

    @Override
    public boolean isValid(JsonObject unit) {
        return has(unit, "id") && has(unit, "name") &&
                has(unit, "lastUpdated");
    }

    @Override
    protected void vitalInfo(StringBuilder info, JsonObject unit) {
        if (has(unit, "id"))
            info.append(" id: ").append(unit.get("id"));
        if (has(unit, "name"))
            info.append(" name: ").append(unit.get("name"));
    }
}